@@ -1,8 +1,10 @@
 import os
 import streamlit.components.v1 as components
+from typing import List,Set
 import json
 
 # python setup.py sdist bdist_wheel
+# twine upload  dist/*
 
 _RELEASE = True
 
@@ -86,6 +88,36 @@ class Edge:
   def to_dict(self):
     return self.__dict__
 
+class Triple:
+  def __init__(self, subj: Node, pred: Edge, obj:Node ) -> None:
+    self.subj = subj
+    self.pred = pred
+    self.obj = obj
+
+class TripleStore:
+  def __init__(self) ->None:
+    self.nodes_set: Set[Node] = set()
+    self.edges_set: Set[Edge] = set()
+    self.triples_set: Set[Triple] = set()
+
+  def add_triple(self, node1, link, node2, picture=""):
+    nodeA = Node(node1, svg=picture)
+    nodeB = Node(node2)
+    edge = Edge(source=nodeA.id, target=nodeB.id, labelProperty=link, renderLabel=True)  # linkValue=link
+    triple = Triple(nodeA, edge, nodeB)
+    self.nodes_set.update([nodeA, nodeB])
+    self.edges_set.add(edge)
+    self.triples_set.add(triple)
+
+  def getTriples(self)->Set[Triple]:
+    return self.triples_set
+
+  def getNodes(self)->Set[Node]:
+    return self.nodes_set
+
+  def getEdges(self)->Set[Edge]:
+    return self.edges_set
+
 # def parse_node(*args):
 #  nodes_data = [{"id": f"{node}"} for node in nodes]
 
